@@ -2,7 +2,7 @@
 ###################ETAs IN BASELINE & SLOPE/EC50 w/o BOV for PERD##################
 ###################################################################################
 
-myModeling11 <- function(myData, AIC.k){
+myModeling11 <- function(myData, AIC.k, delay.confidence){
 
   #library(nlme)
 
@@ -27,7 +27,8 @@ myModeling11 <- function(myData, AIC.k){
 
   try(stop(""),TRUE)
   results.nlme.ETA.BL.SLO.EC50.noBOV <- data.frame()
-
+  saved.models = list()
+  
   #################Estimated E0############################################
 
   ##Mod01-E0+Slope
@@ -46,7 +47,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$AIC <- AIC(my.nlme, k = AIC.k)
     tmp$SLOPE <- extract.num["value.Slo"]
     tmp$VAR.SLOPE <- extract.num["cov.Slo.Slo"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -71,7 +73,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$VAR.EMAX <- extract.num["cov.Emax.Emax"]
     tmp$VAR.EC50 <- extract.num["cov.EC50.EC50"]
     tmp$COV.EMAX.EC50 <- extract.num["cov.Emax.EC50"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -100,7 +103,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$COV.EMAX.EC50 <- extract.num["cov.Emax.EC50"]
     tmp$COV.EMAX.HILL <- extract.num["cov.Emax.Hill"]
     tmp$COV.EC50.HILL <- extract.num["cov.EC50.Hill"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -110,7 +114,7 @@ myModeling11 <- function(myData, AIC.k){
 
   ##Mod04-E0/fNTAFD+Slope
   tmp <- dfEmpty
-  tmp$MODEL <- "19, model = e0~fNTAFD + slope, bsv = e0~fNTAFD + slope"
+  tmp$MODEL <- "19, model = e0~fNTAFD + slope, bsv = e0 + slope"
   suppressWarnings(try({
     my.nlme <- nlme(RESPONSE~.my.intercept.fun(Int)+.my.slope.fun(Slo, Conc=EXPOSURE),
                     data=myData,
@@ -124,7 +128,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$AIC <- AIC(my.nlme, k = AIC.k)
     tmp$SLOPE <- extract.num["value.Slo"]
     tmp$VAR.SLOPE <- extract.num["cov.Slo.Slo"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -132,7 +137,7 @@ myModeling11 <- function(myData, AIC.k){
 
   ##Mod05-E0/fNTAFD+Emax
   tmp <- dfEmpty
-  tmp$MODEL <- "20, model = e0~fNTAFD + emax, bsv = e0~fNTAFD + ec50"
+  tmp$MODEL <- "20, model = e0~fNTAFD + emax, bsv = e0 + ec50"
   suppressWarnings(try({
     my.nlme <- nlme(RESPONSE~.my.intercept.fun(Int)+.my.Emax.fun(Emax, EC50, Conc=EXPOSURE),
                     data=myData,
@@ -149,7 +154,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$VAR.EMAX <- extract.num["cov.Emax.Emax"]
     tmp$VAR.EC50 <- extract.num["cov.EC50.EC50"]
     tmp$COV.EMAX.EC50 <- extract.num["cov.Emax.EC50"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -157,7 +163,7 @@ myModeling11 <- function(myData, AIC.k){
 
   ##Mod06-E0/fNTAFD+SigEmax
   tmp <- dfEmpty
-  tmp$MODEL <- "21, model = e0~fNTAFD + sigmoidal emax, bsv = e0~fNTAFD + ec50"
+  tmp$MODEL <- "21, model = e0~fNTAFD + sigmoidal emax, bsv = e0 + ec50"
 
   suppressWarnings(try({
     my.nlme <- nlme(RESPONSE~.my.intercept.fun(Int)+.my.sigEmax.fun(Emax, EC50, Hill, Conc=EXPOSURE),
@@ -179,7 +185,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$COV.EMAX.EC50 <- extract.num["cov.Emax.EC50"]
     tmp$COV.EMAX.HILL <- extract.num["cov.Emax.Hill"]
     tmp$COV.EC50.HILL <- extract.num["cov.EC50.Hill"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -204,7 +211,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$AIC <- AIC(my.nlme, k = AIC.k)
     tmp$SLOPE <- extract.num["value.Slo"]
     tmp$VAR.SLOPE <- extract.num["cov.Slo.Slo"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -231,7 +239,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$VAR.EMAX <- extract.num["cov.Emax.Emax"]
     tmp$VAR.EC50 <- extract.num["cov.EC50.EC50"]
     tmp$COV.EMAX.EC50 <- extract.num["cov.Emax.EC50"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -262,7 +271,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$COV.EMAX.EC50 <- extract.num["cov.Emax.EC50"]
     tmp$COV.EMAX.HILL <- extract.num["cov.Emax.Hill"]
     tmp$COV.EC50.HILL <- extract.num["cov.EC50.Hill"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -287,7 +297,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$AIC <- AIC(my.nlme, k = AIC.k)
     tmp$SLOPE <- extract.num["value.Slo"]
     tmp$VAR.SLOPE <- extract.num["cov.Slo.Slo"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -313,7 +324,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$VAR.EMAX <- extract.num["cov.Emax.Emax"]
     tmp$VAR.EC50 <- extract.num["cov.EC50.EC50"]
     tmp$COV.EMAX.EC50 <- extract.num["cov.Emax.EC50"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -344,7 +356,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$COV.EMAX.EC50 <- extract.num["cov.Emax.EC50"]
     tmp$COV.EMAX.HILL <- extract.num["cov.Emax.Hill"]
     tmp$COV.EC50.HILL <- extract.num["cov.EC50.Hill"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -370,7 +383,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$AIC <- AIC(my.nlme, k = AIC.k)
     tmp$SLOPE <- extract.num["value.Slo"]
     tmp$VAR.SLOPE <- extract.num["cov.Slo.Slo"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -397,7 +411,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$VAR.EMAX <- extract.num["cov.Emax.Emax"]
     tmp$VAR.EC50 <- extract.num["cov.EC50.EC50"]
     tmp$COV.EMAX.EC50 <- extract.num["cov.Emax.EC50"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -428,7 +443,8 @@ myModeling11 <- function(myData, AIC.k){
     tmp$COV.EMAX.EC50 <- extract.num["cov.Emax.EC50"]
     tmp$COV.EMAX.HILL <- extract.num["cov.Emax.Hill"]
     tmp$COV.EC50.HILL <- extract.num["cov.EC50.Hill"]
-    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme)
+    tmp$DRUG.EFFECT.DELAY <- cder.regression(myData, my.nlme, delay.confidence)
+    saved.models[[tmp$MODEL]] = my.nlme
   }, silent = T))
   tmp$ERROR.MESSAGE <- geterrmessage()
   try(stop(""),TRUE)
@@ -440,5 +456,5 @@ myModeling11 <- function(myData, AIC.k){
     "none"
 
   #Return results
-  return(results.nlme.ETA.BL.SLO.EC50.noBOV)
+  return(list(results.nlme.ETA.BL.SLO.EC50.noBOV, saved.models))
 }
